
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '36.2.0',
    'branch_nick': 'release-36',
    'revision_id': 'e9fa6a872d7c83dbe41cd74932267cdc5289cfd3',
    'revno': 13451
}
